@@ -48,55 +48,55 @@ summary.nltm <- function(object,  coef = TRUE, conf.int = 0.95,
 
 print.summary.nltm <- function(x, digits = max(options()$digits - 4, 3), ...)
 {
-  cat(gettextf("Authors: G. Garibotti, A. Tsodikov\n"))
+  ## message(gettextf("Authors: G. Garibotti, A. Tsodikov"))
   if(!is.null(x$call)) {
-    cat("Call:\n")
-    dput(x$call)
-    cat("\n")
+    message("Call:")
+    message(deparse(x$call))
+    message()
   }
 
   if(!is.null(x$convergence)){
     if(x$convergence==1){
-      cat("Iteration limit maxit: ", x$maxit, " has been reached.\n")
-      cat("Consider a new initial value or optimization parameters such",
-          "as bscale.\n",sep=" ")
-      cat("See nltm.control help\n")
+      message("Iteration limit maxit: ", x$maxit, " has been reached.")
+      message("Consider a new initial value or optimization parameters such",
+          "as bscale.",sep=" ")
+      message("See nltm.control help")
     }else{
       if(x$convergence==51){
-        cat("Warning from optimization method: ", x$message, "\n")
-        cat("Consider a new initial value or optimization parameters such",
-            "as bscale.\n", sep=" ")
-        cat("See nltm.control help\n")
+        message("Warning from optimization method: ", x$message)
+        message("Consider a new initial value or optimization parameters such",
+            "as bscale.", sep=" ")
+        message("See nltm.control help")
       }else{
         if(x$convergence==52){
-          cat("Error in optimization method: ", x$message, "\n")
-          cat("Consider a new initial value or optimization parameters such",
-              "as bscale.\n", sep=" ")
-          cat("See nltm.control help\n")
+          message("Error in optimization method: ", x$message)
+          message("Consider a new initial value or optimization parameters such",
+              "as bscale.", sep=" ")
+          message("See nltm.control help")
         }
       }
     }
 
     negVar <- which(diag(x$var)<=0)
     if(length(negVar)>0){
-      cat(gettextf("\nWarning message:\n"))
-      cat(gettextf("Problem with covariance matrix of coefficients.\n"))
-      cat(gettextf("Some diagonal terms are negative.\n"))
-      cat(gettextf("p-values and confidence intervals are unreliable.\n\n\n"))
+      message(gettextf("\nWarning message:"))
+      message(gettextf("Problem with covariance matrix of coefficients."))
+      message(gettextf("Some diagonal terms are negative."))
+      message(gettextf("p-values and confidence intervals are unreliable.\n\n"))
     }
   
     savedig <- options(digits = digits)
     on.exit(options(savedig))
   
-    cat("Non Linear Transformation Model: ", x$call$nlt.model,
-        ", fit by maximum likelihood\n\n", sep="")
+    message("Non Linear Transformation Model: ", x$call$nlt.model,
+        ", fit by maximum likelihood\n", sep="")
 
     if(x$npred==1){
       if(!is.null(x$coef)) {
         prmatrix(x$coef)
       }
       if(!is.null(x$conf.int)) {
-        cat("\n")
+        message()
         prmatrix(x$conf.int)
       }
     }else{
@@ -106,12 +106,12 @@ print.summary.nltm <- function(x, digits = max(options()$digits - 4, 3), ...)
       if(!is.na(match("cure",dimnames(x$coef)[[1]])))
         ind1 <- c(ind1,dim(x$coef)[1])    
       if(length(ind1)>0){
-        cat("Long term predictor\n")
+        message("Long term predictor")
         if(!is.null(x$coef[ind1,])) 
           prmatrix(matrix(x$coef[ind1,],nrow=length(ind1)),
                    rowlab=rownames(x$coef)[ind1],collab=colnames(x$coef))
         if(!is.null(x$conf.int[ind1,])) {
-          cat("\n")
+          message()
           prmatrix(matrix(x$conf.int[ind1,],nrow=length(ind1)),
                    rowlab=rownames(x$conf.int)[ind1],
                    collab=colnames(x$conf.int))
@@ -119,32 +119,32 @@ print.summary.nltm <- function(x, digits = max(options()$digits - 4, 3), ...)
       }
       ind1 <- setdiff(1:dim(x$coef)[1],ind1)    
       if(length(ind1>0)){
-        cat("\nShort term predictor\n")
+        message("\nShort term predictor")
         if(!is.null(x$coef[ind1,]))
           prmatrix(matrix(x$coef[ind1,],nrow=length(ind1)),
                    rowlab=rownames(x$coef)[ind1],collab=colnames(x$coef))
         if(!is.null(x$conf.int[ind1,])) {
-          cat("\n")
+          message()
           prmatrix(matrix(x$conf.int[ind1,],nrow=length(ind1)),
                    rowlab=rownames(x$conf.int)[ind1],
                    collab=colnames(x$conf.int))
         }
       }
     }
-    cat("\n")
-    cat("Likelihood ratio test=", format(round(x$logtest["test"], 2)),
+    message()
+    message("Likelihood ratio test=", format(round(x$logtest["test"], 2)),
         " on ", x$logtest["df"], " df, p=", format(x$logtest["pvalue"]),
         sep="")
-    cat("\n")
+    message()
     
     omit <- x$na.action
     if(length(omit))
-      cat("n=", x$n, " (", naprint(omit), ")\n", sep="")
-    else cat("n=", x$n, "\n",sep="")
+      message("n=", x$n, " (", naprint(omit), ")", sep="")
+    else message("n=", x$n, "\n",sep="")
   }else{
-    cat("Null model: ",x$call$nlt.model,"\n",sep="")
-    cat("Likelihood=", format(round(x$loglik[1], digits)), " n=", x$n, "\n",
+    message("Null model: ",x$call$nlt.model,sep="")
+    message("Likelihood=", format(round(x$loglik[1], digits)), " n=", x$n,
         sep="")
   }
-  invisible()
+  invisible(x)
 }
